Learn R Programming

sensobol (version 1.1.6)

print.sensobol: Display the results obtained with the sobol_indices function.

Description

Display the results obtained with the sobol_indices function.

Usage

# S3 method for sensobol
print(x, ...)

Value

The function print.sensobol informs on the first and total-order estimators used in the computations, the total number of model runs and the sum of first-order index. It also plots the estimated results.

Arguments

x

A sensobol object produced by sobol_indices.

...

Further arguments passed to or from other methods.