Learn R Programming

sensobol (version 1.1.6)

print.vars: Display the results obtained with the vars_to function.

Description

Display the results obtained with the vars_to function.

Usage

# S3 method for vars
print(x, ...)

Value

The function print.vars informs on the number of star centers, the value of h used and the total number of model runs.. It also plots the VARS-TO indices.

Arguments

x

A vars object produced by vars_to.

...

Further arguments passed to or from other methods.